#
# spec file for package minikube
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           minikube
Version:        1.31.2
Release:        1.1
Summary:        Tool to run Kubernetes locally
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/kubernetes/minikube
Source0:        https://github.com/kubernetes/minikube/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        %{name}-rpmlintrc
BuildRequires:  git-core
BuildRequires:  golang-github-jteeuwen-go-bindata
BuildRequires:  golang-packaging
BuildRequires:  libvirt-devel >= 1.2.14
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  wget
BuildRequires:  zstd
BuildRequires:  golang(API) = 1.20
Recommends:     docker-machine-driver-kvm2
Recommends:     kubernetes-client
Recommends:     libvirt
Recommends:     libvirt-daemon-qemu
Recommends:     qemu-kvm
ExcludeArch:    ppc64le s390x

%description
Minikube is a tool that allows running Kubernetes locally. Minikube
runs a single-node Kubernetes cluster inside a VM on your machine for
users looking to try out Kubernetes or develop with it day-to-day.

# vendor/github.com/libvirt/libvirt-go/domain_events.go:334: type [1073741824]_Ctype_struct__virDomainEventGraphicsSubjectIdentity too large
%ifnarch i586 %{arm}
%package -n docker-machine-driver-kvm2
Summary:        KVM driver for docker-machine
Group:          System/Management

%description -n docker-machine-driver-kvm2
KVM driver for docker-machine which is using libvirt for setting up
virtual machines with Docker.
%endif

%package        bash-completion
Summary:        Minikube bash completion
Group:          System/Management
BuildRequires:  bash
BuildRequires:  bash-completion
Requires:       bash
Requires:       bash-completion
Requires:       minikube = %{version}
Supplements:    (minikube and bash)
BuildArch:      noarch

%description    bash-completion
Optional bash completion for minikube.

%prep
%autosetup
tar -xf %{SOURCE1}
sed -i -e "s|GO111MODULE := on|GO111MODULE := off|" Makefile

%build
%{goprep} k8s.io/minikube
export GOPATH=%{_builddir}/go
cd $GOPATH/src/k8s.io/minikube
mkdir $GOPATH/bin
ln -s %{_bindir}/go-bindata $GOPATH/bin/go-bindata
export IN_DOCKER=0
git config --global user.email "you@example.com"
git config --global user.name "Your Name"
git init
echo '*' > .gitignore
touch .dummy
git add -f .dummy .gitignore
d=$(date "-d@${SOURCE_DATE_EPOCH:-$(date +%%s)}" +"%%Y-%%m-%%d %%H:%%M:%%S")
GIT_COMMITTER_DATE="$d" git commit --date="$d" -m "trick hack/get_k8s_version.py"
%make_build out/minikube
%ifnarch i586
%ifarch aarch64
%make_build out/docker-machine-driver-kvm2-arm64
%else
%make_build out/docker-machine-driver-kvm2
%endif
%endif

%{_builddir}/go/src/k8s.io/minikube/out/%{name} completion bash > %{_builddir}/%{name}-bash-completions

%install
output_path="%{_builddir}/go/src/k8s.io/minikube/out/"
binaries=(minikube)
install -m 755 -d %{buildroot}%{_bindir}
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/minikube
%ifnarch i586
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/docker-machine-driver-kvm2*
%ifarch aarch64
# Add a symlink without '-arm64' suffix
pushd %{buildroot}%{_bindir}
ln -s docker-machine-driver-kvm2* docker-machine-driver-kvm2
popd
%endif
%endif

install -D -m 0644 %{_builddir}/%{name}-bash-completions \
    %{buildroot}%{_datadir}/bash-completion/completions/%{name}

%files
%license LICENSE
%doc CHANGELOG.md CONTRIBUTING.md README.md
%{_bindir}/minikube

%ifnarch i586
%files -n docker-machine-driver-kvm2
%license LICENSE
%{_bindir}/docker-machine-driver-kvm2*
%endif

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Tue Oct 17 2023 Dirk Müller <dmueller@suse.com>
- update to 1.31.2:
  * docker-env Regression:
  * Create `~/.ssh` directory if missing #16934
  * Fix adding guest to `~/.ssh/known_hosts` when not needed
    [#17030]
  * Verify containerd storage separately from docker #16972
  * cni: Fix regression in auto selection #16912
* Tue Jul 18 2023 Dirk Müller <dmueller@suse.com>
- update to 1.31.0:
  * Add back VMware driver support #16796
  * `docker-env` supports the containerd runtime (experimental)
    [#15452] #16761
  * Automatically renew expired kubeadm certs #16249
  * New addon inspektor-gadget #15869
  * Major Improvements:
  * VM drivers: Fix all images getting removed on stop/start (40%%
    start speedup) #16655
  * Addon registry: Add support for all architectures #16577
  * QEMU: Fix failing to interact with cluster after upgrading
    QEMU version #16853
  * macOS/QEMU: Auto unblock bootpd from firewall if blocking
    socket_vmnet network #16714 #16789
  * `minikube cp` supports providing directory as a target #15519
* Wed Apr  5 2023 Dirk Müller <dmueller@suse.com>
- update to 1.30.1:
  * Docker driver: Fix incorrectly stating `Image was not built
    for the current minikube` #16226
  * Mark VMware driver as unsupported  #16233
* Tue Apr  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.30.0:
  * Ensure only one minikube tunnel instance runs at a time
  * Infer HyperKit HostIP as Gateway rather than hardcode to 192.168.64.1
  * multi-node: Add support for volumes using CSI addon
  * QEMU: Rename user network to builtin and update documentation
  * none driver: Look for cri-dockerd instead of hardcoding
  * Replace instances of k8s.gcr.io with registry.k8s.io
  * Handle CRI config of NetworkPlugin and PauseImage
  * Remove deprecated container-runtime flag from Kubernetes v1.24+
  * none driver: Require crictl to be installed for Kubernetes v1.24+
  * Add cri-dockerd logs to minikube logs output
  * Add ingress logs to minikube logs output
  * Add default cni logs to minikbue logs output
  * Add JSON output option to miniikube service list
  * Add kicbase download process to JSON output
  * Implement --docs for minikube addons list -o json
  * Implement --skip-audit flag and skip adding profile commands to audit log
  * Implement --last-start-only flag to minikube logs to only show last start log
  * see https://github.com/kubernetes/minikube/releases/tag/v1.30.0
* Mon Jan 30 2023 Dirk Müller <dmueller@suse.com>
- update to 1.29.0:
  * Bump QEMU driver priority from experimental to default
  * Ability to set static-ip for Docker driver
  * GCP-Auth Addon: automatically attach credentials to newly created
    namespaces
  * Allow forcing 1 CPU on Linux with docker and none driver
  * Major Improvements:
  * Large improvements to cgroup detection and CNI and CRI configurations
  * Prevent redownloading kicbase when already downloaded
  * Warn when using an old ISO/Kicbase image
  * Check brew install paths for socket_vmnet
  * Include gcp-auth logs in 'minikube logs' output
  * Use absolute path when calling crictl version
  * Add additional memory overhead for VirtualBox when `--memory=max`
  * Update Windows installer to create system-wide shortcut
  * Add `--subnet` validation
  * Add groups check to SSH driver
  * Update references to deprecated beta.kubernetes.io
  * Fix possible race condition when enabling multiple addons #15706
  * Fix cpus config field not supporting max value #15479
  * Fix subnet checking failing if IPv6 network found #15394
  * Fix Docker tunnel failing if too many SSH keys #15560
  * Fix kubelet localStorageCapacityIsolation option #15336
  * Fix setting snapshotter to unimplemented fuse-overlayfs #15272
  * Remove progress bar for kic download with JSON output #15482
  * Version Upgrades:
  * Bump default Kubernetes version from 1.25.3 to 1.26.1 #15683
  * Addons: Update auto-pause from 0.0.2 to 0.0.3 #15331
  * Addons: Update cloud-spanner from 1.4.6 to 1.5.0 #15440 #15667 #15707
  * Addons: Update headlamp from 0.13.0 to 0.14.1 #15401 #15515
  * Addons: Update ingress from 1.2.1 to 1.5.1 #15339
  * Addons: Update metrics-server from 0.6.1 to 0.6.2 #15411
  * Addons: Update kubevirt from 1.17 to 1.24.7 #15310
  * CNI: Update cilium from 1.9.9 to 1.12.3 #15242
  * Kicbase: Update buildkit from 0.10.3 to v0.11.0 #15630
  * Kicbase/ISO: Update containerd from 1.6.9 to 1.6.15 #15541
  * Kicbase/ISO: Update cri-dockerd from 0.2.2 to 0.3.0 #15541
  * Kicbase/ISO: Update docker from 20.10.20 to 20.10.23 #15341 #15541
  * Update KVM-docker-machine amd64 base image from Ubuntu 16.04 to 20.04
  * For a more detailed changelog see CHANGELOG.md.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to v1.28.0:
  * SECURITY WARNING: Log4j CVEs were detected in an image the efk addon uses,
  * if you don't use the efk addon no action is required. If you use the addon
  * we recommend running minikube addons disable efk to terminate the
  * vulnerable pods.  See #15280 for more details.
  * Prevent enabling efk addon due to containing Log4j CVE #15281
  * Auto select network on QEMU #15266
  * Implement mounting on QEMU with socket_vmnet #15108
  * Added cloud-spanner emulator addon #15160
  * Add minikube license command #15158
  * Allow port forwarding on Linux with Docker Desktop #15126
  * Add back service to mount VirtualBox host directory into the guest. #14784
  * ISO: Add FANOTIFY_ACCESS_PERMISSIONS to kernel configs #15232
  * When enabling addon warn if addon has no associated Github username #15081
  * Fix detecting preload cache of size 0 as valid #15256
  * Fix always writing to daemon by trimming docker.io from image name #14956
  * Fix minikube tunnel repeated printout of status #14933
  * Upgrade Portainer addon to 2.15.1 & HTTPS access enabled #15172
  * Upgrade Headlamp addon to 0.13.0 #15186
  * ISO: Upgrade Docker from 20.10.18 to 20.10.20 #15159
  * KIC: Upgrade base image from ubuntu:focal-20220826 to ubuntu:focal-20220922 #15075
  * KCI: Upgrade base image from ubuntu:focal-20220922 to ubuntu:focal-20221019 #15219
* Tue Oct 11 2022 Steve Kowalik <steven.kowalik@suse.com>
- BuildRequires python3 rather than python.
* Mon Oct 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.27.1:
  * QEMU Driver: Add support for dedicated network on macOS (socket_vmnet) #14989
  * QEMU Driver: Add support minikube service and tunnel on macOS #14989
  * Check if context is invalid during update-context command #15032
  * Use SSH tunnel if user specifies bindAddress #14951
  * Warn QEMU users if DNS issue detected #15073
  * Fix status command taking a long time on docker driver while paused #15077
  * Fix not allowing passing only an exposed port to --ports #15085
  * Fix minikube dashboard failing on macOS #15037
  * Fix incorrect command in powershell command tip #15012
* Fri Sep 16 2022 Dirk Müller <dmueller@suse.com>
- update to 1.27.0:
  * Bump default Kubernetes version to v1.25.0 and resolve /etc/resolv.conf regression #14848
  * Skip metallb PodSecurityPolicy object for kubernetes 1.25+ #14903
  * The DefaultKubernetesRepo changed for 1.25.0 #14768
  * Fix QEMU delete errors #14950
  * Fix containerd configuration issue with insecure registries #14482
  * Fix registry when custom images provided #14690
  * ISO: Update Docker from 20.10.17 to 20.10.18 #14935
  * Update kicbase base image to Ubuntu:focal-20220826 #14904
  * Update registry addon image from 2.7.1 to 2.8.1 #14886
  * Update gcp-auth-webhook addon from v0.0.10 to v0.0.11 #14847
  * Update Headlamp addon image from v0.9.0 to v0.11.1 #14802
* Tue Sep 13 2022 Dirk Müller <dmueller@suse.com>
- update to 1.26.1:
  * Check for cri-dockerd & dockerd runtimes when using none-driver on Kubernetes 1.24+ #14555
  * Add solution message for when cri-docker is missing #14483
  * Limit number of audit entries #14695
  * Optimize audit logging #14596
  * Show the container runtime when running without kubernetes #13432 #14200
  * Add warning when enabling thrid-party addons #14499
  * Fix url index out of range error in service #14658
  * Fix incorrect user and profile in audit logging #14562
  * Fix overwriting err for OCI "minikube start" #14506
  * Fix panic when environment variables are empty #14415
  * Bump Kubernetes version default: v1.24.3 and latest: v1.24.3 #14606
  * ISO: Update Docker from 20.10.16 to 20.10.17 #14534
  * ISO/Kicbase: Update cri-o from v1.22.3 to v1.24.1 #14420
  * ISO: Update conmon from v2.0.24 to v2.1.2 #14545
  * Update gcp-auth-webhook from v0.0.9 to v0.0.10 #14670
  * ISO/Kicbase: Update base images #14481
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- build against go1.18 to fix arm64 build
* Thu Jul  7 2022 Matthew Wilks <water261@outlook.com.au>
- update to 1.26.0:
  * Note: Using a minikube cluster created before 1.26.0, using the docker
    container-runtime (default), and plan to upgrade the Kubernetes version to
    v1.24+? After upgrading, you may need to delete & recreate it. none driver
    users, cri-docker is now required to be installed, install instructions.
    See issue #14410 for more info.
  * Add headlamp addon #14315
  * Add InAccel FPGA Operator addon #12995
  * Only set highmem=off for darwin if qemu version is below 7.0 or memory is below 3GB #14291
  * Define qemu as a qemu2 driver alias #14284
  * Allow users to supply custom QEMU firmware path #14283
  * Add eBPF related kernel options #14316
  * Add bind address flag for minikube tunnel #14245
  * Add active column for minikube profile list #14079
  * Add documentation URL to the addon list table #14123
  * minikube config defaults kubernetes-version lists all currently supported Kubernetes versions #13775
  * Fix terminated commands not writing to audit log #13307
  * Fix Podman port mapping publish on macOS #14290
  * Fix minikube delete deleting networks from other profiles #14279
  * Bump Kubernetes version default: v1.24.1 and latest: v1.24.1 #14197
  * ISO: Upgrade Docker from 20.10.14 to 20.10.16 #14153
  * ISO: Upgrade kernel from 4.19.235 to 5.10.57 #12707
  * Upgrade Dashboard addon from v2.5.1 to v2.6.0 & MetricsScraper from v1.0.7 to v1.0.8 #14269
  * Upgrade gcp-auth-webhook from v0.0.8 to v0.0.9 #14372
  * Upgrade nginx image from v1.2.0 to v1.2.1 #14317
  * Important Changes in Pre-Release Versions
  * Add configure option to registry-aliases addon #13912
  * Add support for building aarch64 ISO #13762
  * Support rootless Podman driver (Usage: minikube config set rootless true) #13829
  * QEMU:
  * Add support for the QEMU driver #13639
  * Fix qemu firmware path locations #14182
  * Re-establish apiserver tunnel on restart #14183
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 1.25.2:
  * add arch to binary and image cache paths #13539
  * Adds 'minikube service --all' feature to allow forwarding all services in a namespace #13367
  * Make the default container runtime dynamic #13251
  * Add --disable-optimizations flag #13340
  * Fix losing cluster on restart #13506
  * Using Get-CmiInstance to detect Hyper-V availability #13596
  * Fixes validation on image repository URL when it contains port but no scheme #13053
  * Fixed SIGSEGV in kubectl when k8s not running #13631
  * Fix hard coded docker driver in minikube service command #13514
  * Fix hard coded docker driver in minikube tunnel command #13444
  * Fix IstioOperator CustomResourceDefinition for istio-provisioner addon #13024
  * fix ingress (also for multinode clusters) #13439
  * Add exit message for too new Kubernetes version #13354
  * drivers/kvm: Use ARP for retrieving interface ip addresses #13482
  * kubeadm: allow skipping kube-proxy addon on restart #13538
  * configure container runtimes for clusters without Kubernetes too #13442
* Fri Jan 28 2022 Dirk Müller <dmueller@suse.com>
- update to 1.25.1:
  * New flag "--binary-mirror" to override mirror URL downloading (kubectl, kubelet, & kubeadm)
  * Add format flag to the image ls command
  * Add all mount flags to start command
  * Auto set config to support btrfs storage driver
  * Support CRI-O runtime with Rootless Docker driver (--driver=docker --container-runtime=cri-o)
  * Allow custom cert for ingress to be overwritten
  * Allow ppc64le & armv7 with Docker driver
  * Support DOCKER_HOST not being numeric IP
  * Support mounting with the --no-kubernetes flag
  * Support changing apiserver-ips when restarting minikube
  * Fix ingress for k8s v1.19
  * Fix mounting with VMware
  * Fix Bad file descriptor on mount
  * Fix docker-env with new PowerShell versions
  * Upgrade Docker, from v20.10.8 to v20.10.11
  * Upgrade containerd, from v1.4.9 to v1.4.12
  * Upgrade cri-o from v1.22.0 to v1.22.1
  * Update gcp-auth-webhook image to v0.0.8
  * mount: Remove --mode flag
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.24.0:
  * Add --no-kubernetes flag to start minikube without kubernetes #12848
  * minikube addons list shows addons if cluster does not exist #12837
  * virtualbox: change default host-only-cidr #12811
  * fix zsh completion #12841
  * Fix starting on Windows with VMware driver on non C: drive #12819
* Tue Oct  5 2021 Klaus Kämpf <kkaempf@suse.com>
- update to 1.23.2:
  Fix crio regression:
  * Roll back default crio cgroup to systemd #12533
  * Fix template typo #12532
- update to 1.23.1:
  Minor Improvements:
  * Add crun version to minikube version --components #12381
  Bug Fixes:
  * ingress addon: fix regression from v1.23.0 #12443
  * ingress addon: fix role resource's referenced configmap #12446
  * ingress-dns addon: fix regression from v1.23.0 #12476
  * gcp-auth addon: delete image pull secrets on addon disable #12473
  * gcp-auth addon: create pull secret even if creds JSON is nil #12461
  * gcp-auth addon: fix refreshing pull secret #12497
  * metallb addon: ask user for config values even if already set #12437
  * ambassador addon: warn on enable that addon no longer works #12474
  * dashboard addon: fix sha for metrics-scraper #12496
  * windows installer: remove quotes from incorrect fields #12430
  * strip namespace from images from aliyun registry #11785
  Version Upgrades:
  * Bump cri-o from v1.20.0 to 1.22.0 #12425
  * Bump dashboard from v2.1.0 to v2.3.1 and metrics-scraper
    from v1.0.4 to v1.0.7 #12475
* Wed Sep  8 2021 Klaus Kämpf <kkaempf@suse.com>
- update to 1.23.0:
  Features:
  * Support Rootless Docker #12359
  * Add support for tcsh in docker-env subcommand #12332
  * Support Ingress on MacOS, driver docker #12089
  * Add support for linux/s390x on docker/podman drivers #12079
  * Add configurable port for minikube mount #11979
  * Add method for customized box output #11709
  * Add addon support for portainer #11933
  * minikube start --image-repository will now accept URLs with port #11585
  * Add ability to create extra disks for hyperkit driver #11483
  * Add ability to create extra disks for kvm2 driver #12351
  minikube image:
  * Add minikube image commands for pull and tag and push #12326
  * new image save command #12162
  * Auto start buildkit daemon on image build for containerd #12076
  Bug fixes:
  * Select WSL VM IP when performing mounting #12319
  * Fix minikube restart on Cloud Shell #12237
  * pause each container separately #12318
  * Add output parameter to the docker-env none shell #12263
  * Clean up ssh tunnels during exit. #11745
  * Fix loading an image from tar failing on existing delete #12143
  * configure gcp-auth addon pull secret to work with all GCR and AR mirrors #12106
  * Fix the error output of minikube version --components command #12085
  * Added restart command after setting crio options #11968
  * Don't set conntrack parameters in kube-proxy #11957
  * Fix kvm2 driver arm64 deb package #11937
  * Allow to set the dashboard proxyfied port #11553
  Version Upgrades:
  * bump golang version to 1.17 #12378
  * Bump default Kubernetes version to v1.22.1 and update addons
    to with new API (ingress, gcpauth, olm and cilium) #12325
  * Add kubeadm image versions for kubernetes 1.22 #12331
  * bump calico to v3.20 and move away from v1beta apis #12230
  * Upgrade Buildroot to 2021.02 LTS with Linux 4.19 #12268
  * Upgrade buildkit from 0.8.2 to 0.9.0 #12032
  * ISO: Upgrade Docker, from 20.10.6 to 20.10.8 #12122
  * ISO: Upgrade crictl (from cri-tools) to v1.21.0 #12129
* Tue Jul 13 2021 Klaus Kämpf <kkaempf@suse.com>
- update to 1.22.0:
  Features:
  * minikube version: add --components flag to list all included
    software #11843
  Minor Improvements:
  * auto-pause: add support for other container runtimes #11834
  * windows: support renaming binary to kubectl.exe and running as
    kubectl #11819
  Bugs:
  * Fix "kubelet Default-Start contains no runlevels" error #11815
  Version Upgrades:
  * bump default kubernetes version to v1.21.2 & newest kubernetes
    version to v1.22.0-beta.0 #11901
* Tue Jul  6 2021 Klaus Kämpf <kkaempf@suse.com>
- update to 1.21.0:
  Features:
  * Support setting addons from environmental variables #11469
  * Add "resume" as an alias for "unpause" #11431
  * Implement target node option for cp command #11304
  * add more polish translations #11587
  Bugs:
  * Fix delete command for paused kic driver with containerd/crio runtime #11504
  * kicbase: try image without sha before failing #11559
  * bug: return error on invalid function name in extract.TranslatableStrings #11454
  * Prevent downloading duplicate binaries already present in preload #11461
  * gcp-auth addon: do not reapply gcp-auth yamls on minikube restart #11486
  * Disable Non-Active Containers Runtimes #11516
  * Persist custom addon image/registry settings. #11432
  * Fix auto-pause on VMs (detect right control-plane IP) #11438
  Version Upgrades:
  * bump default k8s version to v1.20.7 and newest to v1.22.0-alpha.2 #11525
  * containerd: upgrade io.containerd.runtime.v1.linux to io.containerd.runc.v2 (suppot cgroup v2) #11325
  * metallb-addon: Update metallb from 0.8.2 to 0.9.6 #11410
  * Modify MetricsServer to use v1 api version (instead of v1beta1). #11584
* Fri May  7 2021 Dirk Müller <dmueller@suse.com>
- update to 1.20.0:
  * Add --file flag to 'minikube logs' to automatically put logs into a file. #11240
  * Batch logs output to speedup minikube logs command #11274
  * warn about performance for certain versions of kubernetes #11217
  * Update olm addon to v0.17.0 #10947
  * Update newest supported Kubernetes version to v1.22.0-alpha.1 #11287
* Sat Apr 10 2021 Dirk Müller <dmueller@suse.com>
- update to 1.19.0:
  * allow Auto-Pause addon on VMs #11019
  * Do not allow running darwin/amd64 minikube binary on darwin/arm64 systems #11024
  * Respect memory being set in the minikube config #11014
  * new command image ls to list images in a cluster #11007
* Fri Mar  5 2021 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.81.1
  Features:
    kvm2 driver: Add flag --kvm-numa-count" support topology-manager
    simulate numa #10471
  Minor Improvements:
    Spanish translations #10687
    Change podman priority to default on Linux #10458
  Bug Fixes:
    Remove WSLENV empty check from IsMicrosoftWSL #10711
    Added WaitGroups to prevent stderr/stdout from being empty in error logs #10694
  Version changes:
    Restore kube-cross build image and bump go to version 1.16 #10691
    Bump github.com/spf13/viper from 1.7.0 to 1.7.1 #10658
* Tue Mar  2 2021 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.18.0
  Bug Fixes:
    fix: metric server serve on all ipv4 interfaces #10613
- Update to 1.18.0-beta.0
  Features:
    Auto-pause addon: automatically pause Kubernetes when not in use #10427
    GCP Auth addon: bump to v0.0.4 for multiarch #10361
    Add new command: image load #10366
    Add faster profile list command with -l or --light option. #10380
    Add last start logs to 'minikube logs' output #10465
    Introduce alias 'native' for 'none' driver #10540
    Add audit logs to 'minikube logs' output #10350
    Allow setting custom images for addons #10111
  Minor Improvements:
    Deb package: make sure to update the package metadata #10420
    Improve the error message of setting cgroup memory limit. #10575
    SSH driver: Don't select Discouraged or Obsolete by default #10554
    drop support for github packages for kicbase #10582
    disable minikube-scheduled-stop.service until a user schedules a stop #10548
    docker/podman: add crun for running on cgroups v2 #10426
    Specify mount point for cri-o config #10528
    Ensure addon integrity by adding Image SHA #10527
    improve kvm network delete/cleanup #10479
    docker/podman: avoid creating overlapping networks with other tools (KVM,...) #10439
    Improve insecure registry validation #10493
    Stop using --memory-swap if it is not available #10507
    UI: do not send image repo info to stderr #10462
    add new extra component to --wait=all to validate a healthy cluster #10424
    Add condition to check --cpus count with available cpu count #10388
    Disable all drivers except "docker" and "ssh" on darwin/arm64 #10452
    Podman: explicitly remove podman volume and network #10435
    Disallow running windows binary (.exe) inside WSL #10354
    adding insecure registry support to containerd runtime #10385
    Docker driver: support ancient versions of docker #10369
  Bug Fixes:
    cgroup v2: skip setting --memory limits when not configurable. #10512
    metallb addon: fix configuration empty load balancing IP range #10395
    Fixed bug where tmp dir incorrectly set for Snap package manager #10372
    Fixed audit.json error when delete --purge ran #10586
    Fix exit message for insufficient memory #10553
    Fix minikube kubectl context switching #10535
    SSH driver: Make sure that ssh driver gets an ip address #10309
    Fix profile list when there are multi node clusters #9996
    Don't allow profile names that conflict with a multi-node name #10119
  Version changes:
    Buildroot 2020.02.10 #10348
    Change from crio-1.19 to crio-1.20 in kicbase #10477
    bump oldest kubernetes version to v1.14.0, bump default kubernetes version #10531
    Upgrade crio to 1.20.0 #10476
    Upgrade Docker, from 20.10.2 to 20.10.3 #10417
* Sat Feb 27 2021 Chris Coutinho <chrisbcoutinho@gmail.com>
- Update to 1.17.1
  Features:
    Add new flag --user and to log executed commands #10106
    Unhide --schedule flag for scheduled stop #10274
  Bugs:
    fixing debian and arch concurrent multiarch builds #9998
    configure the crictl yaml file to avoid the warning #10221
- Update to 1.17.0
  Features:
    Add multi-arch (arm64) support for docker/podman drivers #9969
    Add new driver "SSH" to bootstrap generic minkube clusters over ssh #10099
    Annotate Kubeconfig with 'Extension' to identify contexts/clusters created by minikube #10126
    Add support for systemd cgroup to containerd runtime #10100
    Add --network flag to select docker network to run with docker driver #9538
  Minor Improvements:
    Improve exit codes by splitting PROVIDER_DOCKER_ERROR into more specific reason codes #10212
    Improve warning about the suggested memory size #10187
    Remove systemd dependency from none driver #10112
    Delete the existing cluster if guest driver mismatch #10084
    Remove obsolete 'vmwarefusion' driver, add friendly message #9958
    UI: Add a spinner for creating container step #10024
    Added validation for --insecure-registry values #9977
  Bug Fixes:
    Snap package manger: fix cert copy issue #10042
    Ignore non-socks5 ALL_PROXY env var when checking docker status #10109
    Docker-env: avoid race condition in bootstrap certs for parallel runs #10118
    Fix 'profile list' for multi-node clusters #9955
    Change metrics-server pull policy to IfNotPresent #10096
    Podman driver: Handle installations without default bridge #10092
    Fix docker inspect network go template for network which doesn't have MTU #10053
    Docker/Podman: add control-plane to NO_PROXY #10046
    "cache add": fix command error when not specifying :latest tag #10058
    Networking: Fix ClusterDomain value in kubeadm KubeletConfiguration #10049
    Fix typo in the csi-hostpath-driver addon name #10034
  Upgrades:
    bump default Kubernetes version to v1.20.2 and add v1.20.3-rc.0 #10194
    Upgrade Docker, from 20.10.1 to 20.10.2 #10154
    ISO: Added sch_htb, cls_fw, cls_matchall, act_connmark and ifb kernel modules #10048
    ISO: add XFS_QUOTA support to guest vm #9999
* Mon Dec 21 2020 Dirk Müller <dmueller@suse.com>
- update to 1.16.0:
  * fix ip node retrieve for none driver #9986
  * remove experimental warning for multinode #9987
  * Enable Ingress Addon for Docker Windows #9761
  * Bump preload to v8 to include updated dashboard #9984
  * Add ssh-host command for getting the ssh host keys #9630
  * Added sub-step logging to adm init step on start #9904
  * Add --node option for command ip and ssh-key #9873
  * Upgrade Docker, from 20.10.0 to 20.10.1 #9966
  * Upgrade kubernetes dashboard to v2.1.0 for 1.20 #9963
  * Upgrade buildkit from 0.8.0 to 0.8.1 #9967
* Fri Dec 18 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Override build date to make package build more reproducible
  (boo#1047218)
* Mon Dec 14 2020 Michał Rostecki <mrostecki@suse.com>
- Remove %%check section - minikube tests require Internet acceess
  and we will be never able to run them on OBS.
* Mon Dec 14 2020 Dan Čermák <dcermak@suse.com>
- Add bash completion subpackage
- use %%make_build and %%autosetup macros
* Tue Nov 17 2020 Michał Rostecki <mrostecki@suse.com>
- Update to 1.15.1:
  Features:
  * Add Support for driver name alias
  * Add support for latest kubernetes version v1.20.0-beta.1
  * Implement schedule stop for unix
  * New flag --watch flag for minikube status with optional interval duration
  * New flag --namespace for activating non default kubeconfig context
  * Add JSON output to stop, pause and unpause
  * Add support for podman v2 to podman-env command
  * Support ImageRepository for addons
  Bug fixes:
  * less verbose language selector
  * implement "--log_file" and "--log_dir" for klog
  * GCP Auth Addon: support special location for cloud shell
  * Enable TCP Path MTU Discovery when an ICMP black hole is detected
  * Remove hard-coded list of valid cgroupfs mountpoints to bind mount
  * Improve parsing of start flag apiserver-names
  * kvm: recover from minikube-net network left over failures
  * fix help flag 'pflag: help requested' error
  * Update "parallels" driver library and make this driver built into minikube
  Minor Improvements:
  * Upgrade crio to 1.18.4
  * Update ingress-nginx image to v0.40.2
  * Improving log message when profile not found
  * Upgrade buildroot and kernel minor version
* Tue Nov 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.14.2:
  * fix "profile list" timing out when cluster stopped.
  * new --wait flag component "kubelet"
  * docker: When creating networks, use MTU of built-in bridge network
  * multinode: ensure worker node join control plane on restart
  * Fix "--native-ssh" flag for "minikube ssh"
  * Fix parallels driver initialization
  * Delete context when stopped
  * New flag "--ports" to expose ports for docker & podman drivers
  * Ingress addon: fix the controller name
* Fri Sep 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.13.1:
  * Update Default Kubernetes Version to v1.19.2 #9265
  * fix mounting for docker driver in windows #9263
  * CSI Hostpath Driver & VolumeSnapshots addons #8461
  * docker/podman drivers: Make sure CFS_BANDWIDTH is available for --cpus #9255
  * Fix ForwardedPort for podman version 2.0.1 and up #9237
  * Avoid setting time for memory assets #9256
  * point to newest gcp-auth-webhook version #9199
  * Set preload=false if not using overlay2 as docker storage driver #8831
  * Upgrade crio to 1.17.3 #8922
  * Add Docker Desktop instructions if memory is greater than minimum but less than recommended #9181
  * Update minimum memory constants to use MiB instead of MB #9180
* Fri Sep  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.13.0:
  * Update default Kubernetes version to v1.19.0 tada #9050
  * start: Support for mounting host volumes on start with docker driver #8159
  * start: Add a machine readable reason to all error paths #9126
  * stop: add --keep-context-active flag #9044
  * kubectl: Invoke kubectl if minikube binary is named 'kubectl' #8872
  * Bug fixes
  * docker: Choose the appropriate bridge interface when multiple exist #9062
  * cache: Fix "cache add" for local images by cherry-picking go-containerregistry fix #9160
  * update-context: Fix nil pointer dereference #8989
  * start: Fix --extra-config for scheduler/controllerManager by removing hardcoded values #9136
  * start: Fix --memory flag parsing in minikube start #9033
  * start: Improve overlay module check (behavior & UX) #9163
  * gcp-auth addon: trim whitespace when setting gcp project id #9164
  * cni: Allow flannel CNI to work with kicbase by fixing IP conflict #9046
  * cni: fix multiple node calico-node not ready #9019
  * kic: Retry fix_cgroup on failure #8974
  * json: fix type for kubectl version mismatch to warning #9157
  * json: fix type for latest minikube availability message #9109
  * addon-manager: Add namespace to persistent volume path #9128
  * ssh: respect native-ssh flag #8907
* Wed Aug 19 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.12.3:
  * Make waiting for Host configurable via --wait-timeout flag #8948
  * Ignore localhost proxy started with scheme. #8885
  * Improve error handling for validating memory limits #8959
  * Skip validations if --force is supplied #8969
  * Fix handling of parseIP error #8820
  * GCP Auth Addon: Exit with better error messages #8932
  * Add warning for ingress addon enabled with driver of none #8870
  * Update Japanese translation #8967
  * Fix for a few typos in polish translations #8950
* Wed Aug 12 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.12.2:
  * New Addon: Automated GCP Credentials #8682
  * status: Add experimental cluster JSON status with state transition support #8868
  * Add support for Error type to JSON output #8796
  * Implement Warning type for JSON output #8793
  * Add stopping as a possible state in deleting, change errorf to warningf #8896
  * Use preloaded tarball for cri-o container runtime #8588
  * docker/podman: warn if allocated memory is below limit #8718
  * Enabling metrics addon when someone enables dashboard #8842
  * make base-image respect --image-repository #8880
  * UI: suggest to enable metric-server for full feature dashboard addon. #8863
  * Fix mount issues with Docker/Podman drivers #8780
  * Fix upgrading from minikube 1.9 and older #8782
  * Make restarts in Docker/Podman drivers more reliable #8864
  * update crio to 1.18.3 and kicbase to ubuntu 20.04 #8895
  * Podman downgrade to 1.9.3 for the build command #8774
  * Upgrade kicbase to v0.0.11 #8899
  * update golang version #8781
  * Update external-provisioner for storage provisioner for Kubernetes 1.18 #8610
  * Upgrade storage provisioner image #8909
* Wed Jul 29 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.12.1:
  * Add support for Calico CNI (--cni=calico) #8571
  * Add support for Cilium CNI (--cni=cilium) #8573
  * Fix bugs which prevented upgrades from v1.0+ to v1.12 #8741
  * Add KicBaseImage to existing config if missing (fixes v1.9.x upgrade) #8738
  * multinode: fix control plane not ready on restart #8698
  * none CNI: error if portmap plug-in is required but unavailable #8684
  * ingress addon: bump to latest version #8705
  * Upgrade go version to 1.14.4 #8660
* Wed Jun 24 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on aarch64
- Build only on supported architectures: x86 x86_64 aarch64
* Mon Jun 22 2020 Michał Rostecki <mrostecki@suse.com>
- Update to 1.11.0:
  Features:
  * add 'defaults' sub-command to minikube config
  * addons: add OLM addon
  * addons:: Add Ambassador Ingress controller addon
  * bump oldest k8s version supported to 1.13
  * bump default kubernetes version to 1.18.3
  * Bump helm-tiller 2.16.7 and promote tiller ClusterRoleBinding to v1
  Minor Improvements:
  * docker/podman drivers: add fall back image in docker hub
  * docker/podman drivers: exit with usage when need login to registry
  * multinode: copy apiserver certs only to control plane
  * docker-env: restart dockerd inside minikube on failure
  * wait for kubernetes components on soft start
  * improve minikube status display for one node
  * improve solution message for wrong kuberentes-version format
  Bug fixes:
  * fix HTTP_PROXY env not being passed to docker engine
  * honor --image-repository even if --image-mirror-country is set
  * parallels driver: fix HostIP implementation
  * addon registry: avoid getting stuck on registry port 443
  * respect native-ssh param properly
  * fixed parsing kubernetes version for keywords "latest" or "stable"
  * multinode: make sure multinode clusters survive restarts
  * multinode: delete docker volumes when deleting a node
  * multinode: delete worker volumes for docker driver
  * multinode: recreate existing control plane node correctly
* Wed Dec 25 2019 Michał Rostecki <mrostecki@opensuse.org>
- Update to 1.6.2:
  * Update default k8s version to v1.17.0
  * Make Kubernetes version sticky for a cluster instead of auto-upgrading
  * cache add: load images to all profiles & skip previously cached images
  * Update dashboard to 2.0.0b8 and pre-cache it again
  * Pre-cache the latest kube-addon-manager
  * Add sch_netem kernel module for network emulation
  * Don't use bash as the entrypoint for docker
  * Make lock names uid and path specific to avoid conflicts
  * Remove deprecated annotation storageclass.beta.kubernetes.io
  * show status in profile list
  * Use newer gvisor version
  * Adds dm-crypt support
  * Add performance analysis packages to minikube ISO
  * Offline: always transfer image if lookup fails, always download drivers
  * Update ingress-dns addon
  * Fix update-context to use KUBECONFIG when the env is set
  * Fixed IPv6 format for SSH
  * Add hyperkit version check whether user's hyperkit is newer
  * start: Remove create/delete retry loop
  * Change error text to encourage better issue reports
* Mon Nov 11 2019 Dirk Mueller <dmueller@suse.com>
- update to 1.5.2:
  * Fix node InternalIP not matching host-only address #5427
  * Add helm-tiller addon #5363
  * Add ingress-dns addon #5507
  * Add validation checking for minikube profile #5624
  * add ability to override autoupdating drivers #5640
  * Add option to configure dnsDomain in kubeAdm #5566
  * Added flags to purge configuration with minikube delete #5548
  * Upgrade Buildroot to 2019.02 and VirtualBox to 5.2 #5609
  * Add libmachine debug logs back #5574
  * Add JSON output for addons list #5601
  * Update default Kubernetes version to 1.16.1 #5593
  * Upgrade nginx ingress controller to 0.26.1 #5514
  * Initial translations for fr, es, de, ja, and zh-CN #5466
  * PL translation #5491
  * Warn if incompatible kubectl version is in use #5596
  * Fix crash when deleting the cluster but it doesn't exist #4980
  * Add json output for profile list #5554
  * Allow addon enabling and disabling when minikube is not running #5565
  * Added option to delete all profiles #4780
  * Replace registry-creds addon ReplicationController with Deployment #5586
  * Performance and security enhancement for ingress-dns addon #5614
  * Add addons flag to 'minikube start' in order to enable specified addons #5543
  * Warn when a user tries to set a profile name that is unlikely to be valid #4999
  * Make error message more human readable #5563
  * Adjusted Terminal Style Detection #5508
  * Fixes image repository flags when using CRI-O and containerd runtime #5447
  * fix "minikube update-context" command fail #5626
  * Fix pods not being scheduled when ingress deployment is patched #5519
  * Fix order of parameters to CurrentContext funcs #5439
  * Add solution for VERR_VMX_MSR_ALL_VMX_DISABLED #5460
  * fr: fix translations of environment & existent #5483
  * optimizing Chinese translation #5201
  * Change systemd unit files perm to 644 #5492
  * Default to best-available local hypervisor rather than VirtualBox #5700
  * Update default Kubernetes version to v1.16.2 #5731
  * Add json output for status #5611
  * gvisor: Use chroot instead of LD_LIBRARY_PATH #5735
  * Hide innocuous viper ConfigFileNotFoundError #5732
  * Set Docker open-files limit ( 'ulimit -n') to be consistent with other runtimes #5761
  * Use fixed uid/gid for the default user account #5767
  * Set --wait=false to default but still wait for apiserver #5757
  * kubelet: Pass --config to use kubeadm generated configuration #5697
  * Refactor to remove opening browser and just return url(s) #5718
  * service: fix --url mode #5790
  * Refactor command runner interface, allow stdin writes #5530
  * macOS install docs: minikube is a normal Homebrew formula now #5750
  * Allow CPU count check to be disabled using --force #5803
  * Make network validation friendlier, especially to corp networks
* Mon Sep 30 2019 Michał Rostecki <mrostecki@opensuse.org>
- Update to 1.4.0
  * Update default Kubernetes version to v1.16.0
  * Upgrade dashboard to 2.0.0b4
  * Upgrade addon-manager to v9.0.2, improve startup and reconcile
    latency
  * Add --interactive flag to prevent stdin prompts
  * Automatically install docker-machine-driver-hyperkit if missing
    or incompatible
  * Driver defaults to the one previously used by the cluster
  * Include port names in the 'minikube service' cmd's output
  * Include ISO files as part of a GitHub release
* Mon Jun 24 2019 Dany Marcoux <dmarcoux@suse.com>
- Add libvirt to recommended packages
* Thu May  2 2019 Panagiotis Georgiadis <pgeorgiadis@suse.com>
- Update to 1.0.1
  * Update default Kubernetes version to 1.14.1
  * Add --download-only option to start command
  * Assert that docker has started rather than explicitly restarting it
  * Download ISO image before Docker images, as it's required first
  * update-context is confusing with profiles
  * BugFix: ExecRunner.Copy now parses permissions strings as octal
  * Add user-friendly error messages for VBOX_THIRD_PARTY & HYPERV_NO_VSWITCH
  * Don't enable kubelet at boot, for consistency with other components
  * fix tunnel integration tests for driver None
  * Reroute logs printed directly to stdout
  * Systemd returns error on inactive, so allow that
  * Add known issue: VirtualBox won't boot a 64bits VM when Hyper-V is activated
  * Upgrade Docker, from 18.06.2-ce to 18.06.3-ce
  * Use Reference, allow caching images with both Tag and Digest
  * Added REGISTRY_STORAGE_DELETE_ENABLED environment variable for Registry addon
  * Escape ‘%%’ in console.OutStyle arguments
  * Add port name to service struct used in minikube service
  * Update Hyper-V daemons
  * Avoid surfacing "error: no objects passed to apply" non-error from addon-manager
  * Don't cache images when --vmdriver=none
  * Enable CONFIG_NF_CONNTRACK_ZONES
  * Fixed status checking with non-default apiserver-port.
  * Escape systemd special chars in docker-env
  * Add conformance test script
  * #compdef must be the first line
* Tue Apr  2 2019 Martin Kravec <mkravec@suse.com>
- Update to 1.0.0
  * Update default Kubernetes version to v1.14.0
  * NOTE: To avoid interaction issues, we also recommend updating kubectl to a recent release (v1.13+)
  * Upgrade addon-manager to v9.0 for compatibility with Kubernetes v1.14
  * Add --image-repository flag so that users can select an alternative repository mirror
  * Rename MINIKUBE_IN_COLOR to MINIKUBE_IN_STYLE
  * mount: Allow names to be passed in for gid/uid
  * mount: unmount on sigint/sigterm, add --options and --mode, improve UI
  * --extra-config now work for kubeadm as well
  * start: Set the default value of --cache to true
  * Remove the swap partition from minikube.iso
  * Add solution catalog to help users who run into known problems
  * Automatically propagate proxy environment variables to docker env
  * More reliable unmount w/ SIGINT, particularly on kvm2
  * Remove arch suffixes in image names
  * Issue #3253, improve kubernetes-version error string
  * Update kubeadm bootstrap logic so it does not wait for addon-manager
  * Add explicit kvm2 flag for hidden KVM signature
  * Remove the rkt container runtime
  * Store the toolbox on the disk instead of rootfs
  * fix CHANGE_MINIKUBE_NONE_USER regression from recent changes
  * Do not wait for k8s-app pods when starting with CNI
  * Replace server name in updateKubeConfig if --apiserver-name exists #3878
  * feature-gates via minikube config set
  * Upgrade crio to v1.13.1, skip install.tools target as it isn't necessary
  * Update Ingress-NGINX to 0.23 Release
  * Add addon-manager, dashboard, and storage-provisioner to minikube logs
  * logs: Add kube-proxy, dmesg, uptime, uname + newlines between log sources
  * Skip "pull" command if using Kubernetes 1.10, which does not support it.
  * Allow building minikube for any architecture
  * Windows installer using installation path for x64 applications
  * caching: Fix containerd, improve console messages, add integration tests
  * Fix `minikube addons open heapster`
* Fri Mar  8 2019 Markos Chandras <mchandras@suse.de>
- Update to 0.35.0
  * Update default Kubernetes version to v1.13.4 (latest stable) (gh#kubernetes/minikube#3807)
  * Update docker/machine to fix the AMD bug (gh#kubernetes/minikube#3809)
  * Enable tap and vhost-net in minikube iso (gh#kubernetes/minikube#3758)
  * Enable kernel modules necessary for IPVS (gh#kubernetes/minikube#3783)
  * Add Netfilter xt_socket module to complete support for Transparent Proxying (TPROXY) (gh#kubernetes/minikube#3712)
  * Change DefaultMountVersion to 9p2000.L (gh#kubernetes/minikube#3796)
  * fix incorrect style name mount (gh#kubernetes/minikube#3789)
  * When missing a hypervisor, omit the bug report prompt (gh#kubernetes/minikube#3787)
  * Fix minikube logs for other container runtimes (gh#kubernetes/minikube#3780)
  * Improve reliability of kube-proxy configmap updates (retry, block until pods are up) (gh#kubernetes/minikube#3774)
  * update libvirtd (gh#kubernetes/minikube#3711)
  * Add flag for disabling the VirtualBox VTX check (gh#kubernetes/minikube#3734)
  * Add make target for building a rpm file (gh#kubernetes/minikube#3742)
  * Improve building of deb package (versioning and permissions) (gh#kubernetes/minikube#3745)
  * chown command should be against user $HOME, not roots home directory. (gh#kubernetes/minikube#3719)
* Wed Feb 27 2019 Michal Vyskocil <mvyskocil@opensuse.org>
- Update to 0.34.1
  * Initial implementation of 'console' package for stylized &
    localized console output 😂
  * Podman 1.0.0
  * fix netstat -f error on linux distros
  * Upgrade Docker, from 18.06.1-ce to 18.06.2-ce
  * Upgrade opencontainers/runc to 0a012df
  * Add DeleteCluster to bootstrapper
  * and many more, see CHANGELOG.md
* Tue Jan 22 2019 Nico Kruber <nico.kruber@gmail.com>
- Update to 0.33.1
  * Install upstream runc into /usr/bin/docker-runc
  * Set default Kubernetes version to v1.13.2 (latest stable)
  * Update to opencontainers/runc HEAD as of 2019-01-15
  * Update to crio-bin v1.13.0
  * Write /etc/crictl.yaml when starting
  * Improve failure output when kubeadm init fails
  * Add new VMware unified driver to supported list
  * Fix Windows cache path issues with directory hierarchies and
    lower-case drive letters
  * Avoid out directory, when listing test files
  * Do not include the default CNI config by default
  * Adding more utils tests
  * Add a storage-provisioner-gluster addon
  * Improve the default crio-bin configuration
  * Allow to specify api server port through CLI fix
  * add brew install instructions for hyperkit
  * Added defaultDiskSize setup to hyperkit driver
  * Enable ipvlan kernel module
  * issue# 3499: minikube status missing newline at end of output
  * apiserver health: try up to 5 minutes, add newline
  * Pass network-plugin value to kubelet
  * Fix missing a line break for minikube status
  * Documentation - Updating golang requirement to 1.11
  * Updating e2e tests instructions
  * Defer dashboard deployment until "minikube dashboard" is
    executed
  * Change minikube-hostpath storage class addon from Reconcile
    to EnsureExists
  * Tell user given driver has been ignored if exising VM is
    different
* Sat Dec 22 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to 0.32.0
  * Make Kubernetes v1.12.4 the default
  * Update kubeadm restart commands to support v1.13.x
  * Make "stop" retry on failure.
  * VirtualBox time cleanup: sync on boot, don't run timesyncd
  * Stream cmd output to tests when -v is enabled, and stream SSH output to logs
  * Document None driver docker compatibility
  * Enable host DNS resolution in virtualbox driver by default
  * Fix CRI socket in Kubernetes >= 1.12.0 kubeadmin config
  * Bump dashboard version to v1.10.1
  * Hide KVM signature when using GPU passthrough to support more GPU models
  * Allow ServiceCIDR to be configured via 'service-cluster-ip-range' flag.
  * Save old cluster config in memory before overwriting
  * Change restart policy on gvisor pod
* Tue Dec 11 2018 Panagiotis Georgiadis <pgeorgiadis@suse.com>
- Update to 0.31.0
  * Enable gvisor addon in minikube
  * LoadBalancer emulation with minikube tunnel
  * Add NET_PRIO cgroup to iso
  * Implement a check to see if an ISO URL is valid
  * Update Ingress-NGINX to 0.21 Release
  * Add schedutils to the guest VM for the ionice command (used by k8s 1.12)
  * Remove both the CoreDNS and KubeDNS addons. Let Kubeadm install the correct DNS addon
  * Upgrade Docker, from 17.12.1-ce to 18.06.1-ce
  * Include ISO URL and reduce stutter in download error message
  * Add apiserver check to "status", and block "start" until it's healthy
  * Containerd improvements
  * Only restart docker service if container runtime is docker
  * Restart containerd after stopping alternate runtimes
  * CRI-O improvements
  * Stop docker daemon, when running cri-o
  * Upgrade to crio v1.11.8
  * Add config parameter for the cri socket path
* Wed Oct 17 2018 Michał Rostecki <mrostecki@suse.de>
- Update to 0.30.0 (bsc#1111347)
  * CVE-2018-1002103
    Dashboard vulnerable to DNS rebinding attack
  * Initial support for Kubernetes 1.12+
  * Use "kubectl proxy" instead of a NodePort to expose the
    dashboard
  * Enhance the Ingress Addon
  * Upgrade cni and cni-plugins to release version
  * ensure that /dev has settled before operating
  * Upgrade gluster client in ISO to 4.1.5
  * update nginx ingress controller version to 0.19.0
  * Install crictl from binary instead of from source
  * Switch the source of libmachine to machine-drivers
  * Add psmisc package, for pstree command
* Mon Oct  1 2018 Michał Rostecki <mrostecki@suse.de>
- Change summary and description of docker-machine-driver-kvm2
  * Correct the information about relation between docker-machine
    and KVM (this is KVM driver for docker-machine, not
    docker-machine driver for KVM)
  * Remove authorship info
* Fri Sep 28 2018 Panagiotis Georgiadis <pgeorgiadis@suse.com>
- Update to 0.29.0
  * Update dashboard version to v1.10.0
  * Change default docker storage driver to overlay2
  * support containerd
  * Make CoreDNS default addon
  * Update CoreDNS deployment
  * Upgrade kpod 0.1 to podman 0.4.1
  * Change dependency management to dep
  * fix: --format outputs any string, --https only subsitute http URL scheme
  * Add env variable for default ES_JAVA_OPTS
  * fix(cli): minikube start --mount --mountsting without write permission
  * Allow certificates to be optionally embedded in .kube/config
  * Fix the --cache-images flag
  * Fix vmwarefusion driver
  * Revert "Remove untainting logic."
  * Linux install: Set owner to root
  * Rm localkube
  * Update to go 1.10.1 everywhere
  * Allow to override build date with SOURCE_DATE_EPOC
* Tue Jul 31 2018 mrostecki@suse.de
- Update to 0.28.2
  * Nvidia driver installation fixed
* Wed Jul 11 2018 mrostecki@suse.com
- Include minikube-rpmlintrc as a source
* Fri Jun 29 2018 dmacvicar@suse.de
- Build docker-machine-driver-kvm2 and create a
  sub-package for it (except for i586, due to build failure)
* Thu Jun 28 2018 pgeorgiadis@suse.com
- Update to Version 0.28.0
  * Minikube status command fixes
  * Boot changes to support virsh console
  * ISO changes to update to Linux 4.16
  * ISO changes to support openvswitch/vxlan
  * Docker API version bumped to 1.35
  * Added hyperkit options for enterprise VPN support
  * Caching correct images for k8s version
  * Cache images feature made synchronous, off by default
  * CoreDNS updated to 1.1.3
  * Heapster updated to 1.5.3
  * Fix for clock skew in certificate creation
- Remove makefile-go-bindata.patch - it was accepted upstream
- Remove makefile-goarch.patch - it was accepted upstream
* Wed Jun  6 2018 jengelh@inai.de
- Ensure neutrality of description. Use noun phrase for summary.
* Thu May 24 2018 mrostecki@suse.com
- Update to 0.27.0
  * Start the default network for the kvm2 driver
  * Fix 1.9.x versions of Kubernetes with the kubeadm bootstrapper
  * Switch the ingress addon from an RC to a Deployment
  * Update nginx ingress controller to 0.14.0
  * Disable dnsmasq on network for kvm driver
* Mon Apr 23 2018 mrostecki@suse.com
- Update to 0.26.1
  * Mark hyperkit, kvm2 and none drivers as supported
  * Bug fix for hyper-v driver
  * Add back CRI preflight ignore
  * Fix preflight checks on clusters <1.9
* Wed Jan  3 2018 gunreben@t-online.de
- Fix Makefile to build for architectures different than AMD64
* Tue Oct 17 2017 dmacvicar@suse.de
- Update to 0.22.3
  * Update dnsmasq to 1.14.5
  * Windows cache path fix
  * Windows path fix
  * Components (apiserver, controller-manager, scheduler, kubelet)
    can now be configured in the kubeadm bootstrapper with the
  - -extra-config flag
  * Kubeadm bootstrapper updated to work with Kubernetes v1.8.0
  * OpenAPI registration fix cherry-picked for compatibility with
    kubectl v1.8.0
  * [MINIKUBE ISO] Added cri-o runtime
* Thu Jun  1 2017 fcastelli@suse.com
- Update to 0.19.1
  * Fixed issue where using TPRs could cause localkube to crash
  * Added mount daemon that can be started using minikube start
  - -mount --mount-string="/path/to/mount". Cleanup of mount
    handled by minikube delete
  * Added minikube "none" driver which does not require a VM but
    instead launches k8s components on the host
  * Update kube-dns to 1.14.2
  * Update kubernetes to 1.6.4
  * Added minikube ssh-key command which retrieves the ssh key
    information for the minikubeVM
  * Fixed vbox interface issue with minikube mount
* Mon Apr  3 2017 fcastelli@suse.com
- Update to 0.17.1
  * Removed vendored KVM driver so minikube doesn't have a
    dependency on libvirt-bin
  * [Minikube ISO] Added ethtool
  * [Minikube ISO] Added bootlocal.sh script for custom startup
    options
  * [Minikube ISO] Added version info in /etc/VERSION
  * [Minikube ISO] Bumped rkt to v1.24.0
  * [Minikube ISO] Enabled user namespaces in kernel
  * [Minikube ISO] /tmp/hostpath_pv and /tmp/hostpath-provisioner
    are now persisted
* Sat Feb 11 2017 dmacvicar@suse.de
- Update to 0.16.0
  * Updated minikube ISO to v1.0.6
  * Updated Registry Creds addon to v1.5
  * Added check for minimum disk size
  * Updated kubernetes to v1.5.2
  * [Minikube ISO] Added back in curl, git, and rsync
  * [Minikube ISO] Enabled CONFIG_TUN in kernel
  * [Minikube ISO] Added NFS packages
  * [Minikube ISO] Enabled swapon on start/stop
  * [Minikube ISO] Updated CNI to v0.4.0
  * [Minikube ISO] Fix permissions for /data directory
  * [Minikube ISO] Updated RKT to v1.23.0
  * [Minikube ISO] Added in CoreOS toolbox binary
  * [Minikube ISO] Fixed vboxFS permission error
* Mon Oct 31 2016 fcastelli@suse.com
- Add update-suse-docker-machine-provisioner.patch patch: required
  to use latest SUSE/openSUSE provisioner of docker-machine
* Tue Oct 25 2016 fcastelli@suse.com
- Split the localkube into a dedicated sub-package
* Sun Oct 16 2016 dmacvicar@suse.de
- initial package for 0.11.0
